@@ -2,11 +2,8 @@ package Web::Machine::I18N::en;
 BEGIN {
   $Web::Machine::I18N::en::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Web::Machine::I18N::en::VERSION = '0.13';
-}
 # ABSTRACT: The English support for I18N-ed HTTP information
-
+$Web::Machine::I18N::en::VERSION = '0.14';
 use strict;
 use warnings;
 
@@ -68,7 +65,7 @@ Web::Machine::I18N::en - The English support for I18N-ed HTTP information
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -114,6 +111,10 @@ Fayland Lam <fayland@gmail.com>
 
 =item *
 
+George Hartzell <hartzell@alerce.com>
+
+=item *
+
 Gregory Oschwald <goschwald@maxmind.com>
 
 =item *
@@ -136,7 +137,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2014 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
