@@ -2,11 +2,8 @@ package Web::Machine::Resource;
 BEGIN {
   $Web::Machine::Resource::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Web::Machine::Resource::VERSION = '0.13';
-}
 # ABSTRACT: A base resource class
-
+$Web::Machine::Resource::VERSION = '0.14';
 use strict;
 use warnings;
 
@@ -90,7 +87,7 @@ Web::Machine::Resource - A base resource class
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -542,6 +539,10 @@ Fayland Lam <fayland@gmail.com>
 
 =item *
 
+George Hartzell <hartzell@alerce.com>
+
+=item *
+
 Gregory Oschwald <goschwald@maxmind.com>
 
 =item *
@@ -564,7 +565,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2014 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
