@@ -2,11 +2,8 @@ package Web::Machine::Util::ContentNegotiation;
 BEGIN {
   $Web::Machine::Util::ContentNegotiation::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Web::Machine::Util::ContentNegotiation::VERSION = '0.13';
-}
 # ABSTRACT: Module to handle content negotiation
-
+$Web::Machine::Util::ContentNegotiation::VERSION = '0.14';
 use strict;
 use warnings;
 
@@ -73,7 +70,7 @@ Web::Machine::Util::ContentNegotiation - Module to handle content negotiation
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -148,6 +145,10 @@ Fayland Lam <fayland@gmail.com>
 
 =item *
 
+George Hartzell <hartzell@alerce.com>
+
+=item *
+
 Gregory Oschwald <goschwald@maxmind.com>
 
 =item *
@@ -170,7 +171,7 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2014 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
